@@ -92,10 +92,12 @@ typedef struct {
 typedef struct ESCL_Device {
     struct ESCL_Device *next;
 
+    double    version;
     char     *model_name;
     int       port_nb;
     char     *ip_address;
     char     *is;
+    int       tls;
     char     *uuid;
     char     *type;
     SANE_Bool https;
@@ -146,6 +148,7 @@ typedef struct support
     int min;
     int max;
     int normal;
+    int value;
     int step;
 } support_t;
 
