@@ -21,8 +21,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -385,7 +384,7 @@ SetCalibration (int iHandle, int numPixels, unsigned int *low_vals[3],
       i = j / numLoop;
 
       /* This is obviously not quite right. The values on
-       * the right are approximatly what windows sends */
+       * the right are approximately what windows sends */
       k = (high_vals[0][i] > 0x4000) ? 1000000000 / high_vals[0][i] : 0;	/* 0x6700 */
       pixel->highr[0] = k;
       pixel->highr[1] = k >> 8;
@@ -484,7 +483,7 @@ void
 CircBufferInit (int iHandle, TDataPipe * p, int iBytesPerLine,
 		int bpp, int iMisAlignment, int blksize, int iTransferSize)
 {
-  iHandle = iHandle; /* to avoid compilation warning */
+  (void) iHandle; /* to avoid compilation warning */
   p->buffersize = max (BUFFER_SIZE, 3 * blksize);
 
   if (p->buffer)
@@ -747,7 +746,7 @@ HP5400_SANE_STATIC
 int
 hp5400_test_scan_response (struct ScanResponse *resp, struct ScanRequest *req)
 {
-  req = req; /* to avoid compilation warning */
+  (void) req; /* to avoid compilation warning */
   HP5400_DBG (DBG_MSG, "Scan response:\n");
   HP5400_DBG (DBG_MSG, "  transfersize=%d   htonl-> %d\n", resp->transfersize,
        htonl (resp->transfersize));
@@ -781,7 +780,7 @@ DoAverageScan (int iHandle, struct ScanRequest *req, int code,
   HWParams.iXferHandle = iHandle;
 
   if (InitScan2 (SCAN_TYPE_CALIBRATION, req, &HWParams, &res, 0, code) != 0)
-    return -1;			/* No colour offseting, we want raw */
+    return -1;			/* No colour offsetting, we want raw */
 
   length = htonl (res.xsize) / 6;
 
@@ -829,7 +828,7 @@ DoScan (int iHandle, struct ScanRequest *req, const char *filename, int code,
 /*  int bpp, planes; */
   int i;
 
-  code = code; /*to avoid compilation warning*/
+  (void) code; /*to avoid compilation warning*/
 
   if (res == NULL)
     res = &res_temp;
@@ -1012,7 +1011,7 @@ hp5400_scan (int iHandle, TScanParams * params, THWParams * pHWParams,
   struct ScanResponse res;
   int result;
 
-  pHWParams = pHWParams; /*to avoid compilation warning*/
+  (void) pHWParams; /*to avoid compilation warning*/
 
   HP5400_DBG (DBG_MSG, "\n");
   HP5400_DBG (DBG_MSG, "Scanning :\n");
@@ -1204,7 +1203,7 @@ InitScan2 (enum ScanType scantype, struct ScanRequest *req,
 
   /* Protect scanner from damage. This stops stpuid errors.  It basically
    * limits you to the scanner glass. Stuff like calibrations which need
-   * more access do it safely by fiddling other paramters. Note you can
+   * more access do it safely by fiddling other parameters. Note you can
    * still break things by fiddling the ScanOffset, but that is not yet
    * under user control */
 
