@@ -175,7 +175,7 @@ static struct scanner *scanner_devList = NULL;
 SANE_Status
 sane_init (SANE_Int * version_code, SANE_Auth_Callback authorize)
 {
-  authorize = authorize;        /* get rid of compiler warning */
+  (void) authorize;             /* get rid of compiler warning */
 
   DBG_INIT ();
   DBG (10, "sane_init: start\n");
@@ -225,7 +225,7 @@ sane_get_devices (const SANE_Device *** device_list, SANE_Bool local_only)
   int num_devices=0;
   int i=0;
 
-  local_only = local_only;        /* get rid of compiler warning */
+  (void) local_only;            /* get rid of compiler warning */
 
   DBG (10, "sane_get_devices: start\n");
 
@@ -2550,7 +2550,7 @@ sense_handler (int fd, unsigned char * sensed_data, void *arg)
   DBG (5, "sense_handler: start\n");
 
   /* kill compiler warning */
-  fd = fd;
+  (void) fd;
 
   /* save for later */
   s->rs_info = get_RS_information (sensed_data);
@@ -2754,8 +2754,8 @@ do_cmd(struct scanner *s, int runRS, int shortTime,
   SANE_Status ret = SANE_STATUS_GOOD;
 
   /*shut up compiler*/
-  runRS=runRS;
-  shortTime=shortTime;
+  (void) runRS;
+  (void) shortTime;
 
   DBG(10, "do_cmd: start\n");
 
